import{u as B,D as b,a as h,b as D,c as v,d as w,m as x,f as C}from"./reka-ui-CrWUNNju.js";import{d as c,D as d,u as e,A as f,E as n,h as i,J as O,K as P,e as r,H as _,I as $,f as k,ak as z,b as A,ad as S}from"./lucide-CCrbsyJI.js";import{c as m}from"./index-Cpyo7KMo.js";import{l as y}from"./vueuse-FEBxOGD_.js";const H=c({__name:"Dialog",props:{open:{type:Boolean},defaultOpen:{type:Boolean},modal:{type:Boolean}},emits:["update:open"],setup(t,{emit:a}){const l=B(t,a);return(u,g)=>(r(),d(e(b),f({"data-slot":"dialog"},e(l)),{default:n(p=>[i(u.$slots,"default",O(P(p)))]),_:3},16))}}),j=c({__name:"DialogOverlay",props:{forceMount:{type:Boolean},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(t){const a=t,s=y(a,"class");return(o,l)=>(r(),d(e(h),f({"data-slot":"dialog-overlay"},e(s),{class:e(m)("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 !z-[9999] bg-black/80",a.class)}),{default:n(()=>[i(o.$slots,"default")]),_:3},16,["class"]))}}),K=c({inheritAttrs:!1,__name:"DialogContent",props:{forceMount:{type:Boolean},disableOutsidePointerEvents:{type:Boolean},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array],default:void 0},showCloseButton:{type:Boolean,default:!0}},emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","openAutoFocus","closeAutoFocus"],setup(t,{emit:a}){const s=t,o=a,l=y(s,"class"),u=B(l,o);return(g,p)=>(r(),d(e(D),null,{default:n(()=>[_(j),_(e(v),f({"data-slot":"dialog-content"},{...g.$attrs,...e(u)},{class:e(m)("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 fixed top-[50%] left-[50%] !z-[9999] grid w-full max-w-[calc(100%-2rem)] translate-x-[-50%] translate-y-[-50%] gap-4 rounded-lg border p-6 shadow-lg duration-200 sm:max-w-lg",s.class)}),{default:n(()=>[i(g.$slots,"default"),t.showCloseButton?(r(),d(e(w),{key:0,"data-slot":"dialog-close",class:"ring-offset-background focus:ring-ring data-[state=open]:bg-accent data-[state=open]:text-muted-foreground absolute top-4 right-4 rounded-xs opacity-70 transition-opacity hover:opacity-100 focus:ring- focus:ring-offset-2 focus:outline-hidden disabled:pointer-events-none [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4 mt-2"},{default:n(()=>[_(e(z)),p[0]||(p[0]=k("span",{class:"sr-only"},"Close",-1))]),_:1})):$("",!0)]),_:3},16,["class"])]),_:3}))}}),M=c({__name:"DialogHeader",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(t){const a=t;return(s,o)=>(r(),A("div",{"data-slot":"dialog-header",class:S(e(m)("flex flex-col gap-2 text-center sm:text-left",a.class))},[i(s.$slots,"default")],2))}}),R=c({__name:"DialogTitle",props:{asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(t){const a=t,s=y(a,"class"),o=x(s);return(l,u)=>(r(),d(e(C),f({"data-slot":"dialog-title"},e(o),{class:e(m)("text-lg leading-none font-semibold",a.class)}),{default:n(()=>[i(l.$slots,"default")]),_:3},16,["class"]))}});export{H as _,K as a,M as b,R as c};
