import{c as s}from"./index-Cpyo7KMo.js";import{d as o,b as t,ad as n,u as l,h as c,e as d}from"./lucide-CCrbsyJI.js";const u=o({__name:"Card",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const e=a;return(r,p)=>(d(),t("div",{"data-slot":"card",class:n(l(s)("bg-card text-card-foreground flex flex-col gap-6 rounded-xl border py-6 shadow-sm",e.class))},[c(r.$slots,"default")],2))}});export{u as _};
