import{I as f}from"./InfoHeader-DQ-vmfLb.js";import{I as v}from"./ItemsListing-KtvqXRYj.js";import{_ as I}from"./ProviderDetails.vue_vue_type_style_index_0_lang-DeD5idYB.js";import{f as a,E as _}from"./index-Cpyo7KMo.js";import{d as h,w as b,o as w,r as p,a0 as y,b as k,H as E,D as n,I as l,F as D,e as r}from"./lucide-CCrbsyJI.js";import"./Toolbar-D8YIoiCi.js";import"./vuetify-DEtiqX2e.js";import"./marquee_text_sync-BYmEAdwt.js";import"./vue-router-D-D-f2lE.js";import"./MediaItemThumb-D8fpTfkJ.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-BGdiLcR-.js";import"./vue-i18n-krBRuO6q.js";import"./Container-DYZU9MIY.js";import"./index-kQIztB-E.js";import"./userPreferences-6opwxEkN.js";import"./Button-C0UlHjBg.js";import"./ListItem-CIldTlv1.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-BERW6gDd.js";import"./PanelviewItemCompact-BAfN9DpK.js";import"./color-CcshWhNz.js";import"./qrcode-CCHMWIXh.js";import"./marked-i_gIkIP3.js";import"./vueuse-FEBxOGD_.js";/* empty css            */import"./swiper-YiD1SI-4.js";const W=h({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(d){const t=d,i=p(!1),e=p(),u=async function(){e.value=await a.getPodcast(t.itemId,t.provider)};b(()=>t.itemId,o=>{o&&u()},{immediate:!0}),w(()=>{const o=a.subscribe(_.MEDIA_ITEM_UPDATED,s=>{const m=s.data;e.value?.uri==m.uri&&(e.value=m,i.value=!0)});y(o)});const c=async function(o){return await a.getPodcastEpisodes(t.itemId,t.provider)};return(o,s)=>(r(),k(D,null,[E(f,{item:e.value},null,8,["item"]),e.value?(r(),n(v,{key:0,itemtype:"podcastepisodes","parent-item":e.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":c,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${t.itemId}.${t.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):l("",!0),e.value?(r(),n(I,{key:1,"item-details":e.value},null,8,["item-details"])):l("",!0)],64))}});export{W as default};
