import{c as n,ac as o}from"./index-Cpyo7KMo.js";import{_ as d}from"./index-CooigQVO.js";import{i as p}from"./index-6A2SRgmF.js";import{d as m,D as h,u as r,ad as i,E as f,h as c,e as l,b as g}from"./lucide-CCrbsyJI.js";import{z as s}from"./external-V0X0qkbD.js";const v=m({__name:"InputGroupButton",props:{variant:{default:"ghost"},size:{default:"xs"},class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e;return(t,u)=>(l(),h(r(d),{"data-size":a.size,variant:a.variant,class:i(r(n)(r(p)({size:a.size}),a.class))},{default:f(()=>[c(t.$slots,"default")]),_:3},8,["data-size","variant","class"]))}}),S=m({__name:"FieldDescription",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e;return(t,u)=>(l(),g("p",{"data-slot":"field-description",class:i(r(n)("text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance","last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5","[&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",a.class))},[c(t.$slots,"default")],2))}}),U=e=>s.object({newPassword:s.string().max(128,"Password must be at most 128 characters."),confirmPassword:s.string()}).refine(a=>a.newPassword===a.confirmPassword,{message:e("auth.passwords_must_match"),path:["confirmPassword"]}),z=e=>s.object({username:s.string().min(2,e("auth.username_min_length")).max(50,"Username must be at most 50 characters."),displayName:s.string().max(100,"Display name must be at most 100 characters."),avatarUrl:s.string().refine(a=>!a||s.string().url().safeParse(a).success,{message:"Invalid URL format."}),role:s.string()}),_=e=>s.string().min(1,e("auth.field_required")).max(100,"Token name must be at most 100 characters."),j=e=>s.object({tokenName:_(e)}),k=e=>s.object({username:s.string().min(2,e("auth.username_min_length")).max(50,"Username must be at most 50 characters."),displayName:s.string().max(100,"Display name must be at most 100 characters."),password:s.string().min(8,e("auth.password_min_length")).max(128,"Password must be at most 128 characters."),confirmPassword:s.string(),role:s.enum(o),playerFilter:s.array(s.string()),providerFilter:s.array(s.string())}).refine(a=>a.password===a.confirmPassword,{message:e("auth.passwords_must_match"),path:["confirmPassword"]}),B=e=>s.object({username:s.string().min(2,e("auth.username_min_length")).max(50,"Username must be at most 50 characters."),displayName:s.string().max(100,"Display name must be at most 100 characters."),avatarUrl:s.string().refine(a=>!a||s.string().url().safeParse(a).success,{message:"Invalid URL format."}),role:s.enum(o),password:s.string().max(128,"Password must be at most 128 characters."),confirmPassword:s.string(),playerFilter:s.array(s.string()),providerFilter:s.array(s.string())}).refine(a=>!a.password||a.password===a.confirmPassword,{message:e("auth.passwords_must_match"),path:["confirmPassword"]});export{v as _,U as a,S as b,j as c,k as d,B as e,z as p,_ as t};
