import{c as p}from"./index-Cpyo7KMo.js";import{aa as f,ab as i,ac as m}from"./reka-ui-CrWUNNju.js";import{d as l,D as o,E as c,h as n,ad as _,u as s,e as u,A as d}from"./lucide-CCrbsyJI.js";import{l as v}from"./vueuse-FEBxOGD_.js";const k=l({__name:"Avatar",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e;return(t,r)=>(u(),o(s(f),{"data-slot":"avatar",class:_(s(p)("relative flex size-8 shrink-0 overflow-hidden rounded-full",a.class))},{default:c(()=>[n(t.$slots,"default")]),_:3},8,["class"]))}}),B=l({__name:"AvatarFallback",props:{delayMs:{},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e,t=v(a,"class");return(r,g)=>(u(),o(s(i),d({"data-slot":"avatar-fallback"},s(t),{class:s(p)("bg-muted flex size-full items-center justify-center rounded-full",a.class)}),{default:c(()=>[n(r.$slots,"default")]),_:3},16,["class"]))}}),C=l({__name:"AvatarImage",props:{src:{},referrerPolicy:{},crossOrigin:{},asChild:{type:Boolean},as:{}},setup(e){const a=e;return(t,r)=>(u(),o(s(m),d({"data-slot":"avatar-image"},a,{class:"aspect-square size-full"}),{default:c(()=>[n(t.$slots,"default")]),_:3},16))}});export{k as _,C as a,B as b};
