import{c as r}from"./index-Cpyo7KMo.js";import{A as n}from"./reka-ui-CrWUNNju.js";import{d as s,D as l,u as a,A as i,e as c}from"./lucide-CCrbsyJI.js";import{l as p}from"./vueuse-FEBxOGD_.js";const v=s({__name:"Separator",props:{orientation:{default:"horizontal"},decorative:{type:Boolean,default:!0},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array],default:void 0}},setup(o){const t=o,e=p(t,"class");return(d,u)=>(c(),l(a(n),i({"data-slot":"separator"},a(e),{class:a(r)("bg-border shrink-0 data-[orientation=horizontal]:h-px data-[orientation=horizontal]:w-full data-[orientation=vertical]:h-full data-[orientation=vertical]:w-px",t.class)}),null,16,["class"]))}});export{v as _};
