.header.v-toolbar[data-v-62540998] .v-toolbar-title{margin-inline-start:0px;font-size:large;font-weight:700}.header.v-toolbar[data-v-62540998]{padding-inline-start:4px}.carousel-wrapper[data-v-62540998]{background-color:rgb(var(--v-theme-panel));padding:10px 0 10px 10px;border-radius:5px 0 0 5px}.widget-row[data-v-62540998]{margin-bottom:10px;margin-left:0;padding-left:0}@media(max-width:575px){.widget-row[data-v-62540998]{margin-bottom:4px}.carousel-wrapper[data-v-62540998]{padding:6px 0 6px 6px}}.disabled[data-v-62540998]{opacity:.2}.enabled[data-v-62540998]{opacity:1}.widget-row-panel-item[data-v-62540998]{margin-bottom:10px}.v-slide-group__prev[data-v-62540998]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-62540998]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-62540998]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-62540998]{visibility:hidden}
