.settings-overview[data-v-6d8dccc5]{padding:32px 24px;max-width:1200px;margin:0 auto}.settings-card-view[data-v-6d8dccc5]{display:flex;flex-direction:column;gap:25px}.settings-featured[data-v-6d8dccc5]{display:grid;grid-template-columns:1fr;gap:25px}.settings-grid[data-v-6d8dccc5]{display:grid;grid-template-columns:repeat(auto-fill,minmax(280px,1fr));gap:25px}@media(min-width:960px){.settings-featured[data-v-6d8dccc5],.settings-grid[data-v-6d8dccc5]{grid-template-columns:repeat(2,1fr)}}@media(min-width:1280px){.settings-grid[data-v-6d8dccc5]{grid-template-columns:repeat(3,1fr)}}.setting-card[data-v-6d8dccc5]{cursor:pointer;position:relative;transition:all .2s cubic-bezier(.4,0,.2,1);overflow:hidden;border:1px solid rgba(var(--v-border-color),var(--v-border-opacity))}.setting-card[data-v-6d8dccc5]:hover{transform:translateY(-4px);box-shadow:0 12px 24px #00000026,0 4px 8px #0000001a;border-color:rgba(var(--v-theme-primary),.3)}.setting-card-header[data-v-6d8dccc5]{position:relative;padding:10px 24px}.setting-header-top[data-v-6d8dccc5]{display:flex;align-items:center;justify-content:space-between;margin-bottom:16px}.setting-icon[data-v-6d8dccc5]{width:56px;height:56px;border-radius:12px;display:flex;align-items:center;justify-content:center;transition:transform .2s ease;box-shadow:0 4px 12px #00000026;flex-shrink:0}.setting-card:hover .setting-icon[data-v-6d8dccc5]{transform:scale(1.1) rotate(5deg)}.setting-title[data-v-6d8dccc5]{font-size:1.25rem;font-weight:600;margin-bottom:8px;line-height:1.3}.setting-description[data-v-6d8dccc5]{font-size:.875rem;line-height:1.5;color:rgba(var(--v-theme-on-surface),.7);margin:0}.setting-chevron[data-v-6d8dccc5]{opacity:.4;transition:all .2s ease;display:flex;align-items:center;justify-content:center;width:32px;height:32px;border-radius:50%;background:rgba(var(--v-theme-on-surface),.05);flex-shrink:0}.setting-card:hover .setting-chevron[data-v-6d8dccc5]{opacity:1;transform:translate(4px);background:rgba(var(--v-theme-primary),.1);color:rgb(var(--v-theme-primary))}.settings-list-view[data-v-6d8dccc5]{max-width:800px;margin:0 auto}.settings-list[data-v-6d8dccc5]{padding:0;background:transparent}.settings-list-item[data-v-6d8dccc5]{cursor:pointer;padding:20px 24px;min-height:80px;border-bottom:none;background:transparent}.settings-list-item[data-v-6d8dccc5]:hover{background-color:rgba(var(--v-theme-on-surface),.05)}.list-item-main[data-v-6d8dccc5]{border-radius:10px!important}.setting-list-icon[data-v-6d8dccc5]{width:48px;height:48px;border-radius:12px;display:flex;align-items:center;justify-content:center;box-shadow:0 2px 8px #00000026;flex-shrink:0}.settings-list-item[data-v-6d8dccc5] .v-list-item__prepend{margin-right:8px}.settings-list-item[data-v-6d8dccc5] .v-list-item__prepend .v-icon{margin-inline-end:0!important}.settings-list-item[data-v-6d8dccc5] .v-list-item-title{font-size:1rem;font-weight:600;line-height:1.3}.settings-list-item[data-v-6d8dccc5] .v-list-item-subtitle{font-size:.875rem;line-height:1.5;color:rgba(var(--v-theme-on-surface),.7);margin-top:4px}.settings-list-item[data-v-6d8dccc5] .v-list-item__append{opacity:.4;transition:opacity .2s ease}.settings-list-item[data-v-6d8dccc5]:hover .v-list-item__append{opacity:1}@media(max-width:768px){.settings-featured[data-v-6d8dccc5],.settings-grid[data-v-6d8dccc5]{grid-template-columns:1fr;gap:16px}.settings-overview[data-v-6d8dccc5]{padding:20px 16px}.setting-card-header[data-v-6d8dccc5]{padding:20px 20px 16px}.setting-header-top[data-v-6d8dccc5]{margin-bottom:12px}.setting-icon[data-v-6d8dccc5]{width:48px;height:48px}.setting-chevron[data-v-6d8dccc5]{width:28px;height:28px}.setting-title[data-v-6d8dccc5]{font-size:1.125rem}.settings-list-item[data-v-6d8dccc5]{padding:16px;min-height:72px}.setting-list-icon[data-v-6d8dccc5]{width:40px;height:40px;margin-right:12px}.settings-list-item[data-v-6d8dccc5] .v-list-item-title{font-size:1rem}.settings-list-item[data-v-6d8dccc5] .v-list-item-subtitle{font-size:.813rem}}@media(max-width:480px){.settings-overview[data-v-6d8dccc5]{padding:16px 12px}.setting-card-header[data-v-6d8dccc5],.setting-card-featured .setting-card-header[data-v-6d8dccc5]{padding:16px}.setting-icon-featured[data-v-6d8dccc5]{width:56px;height:56px}.setting-card-featured .setting-title[data-v-6d8dccc5]{font-size:1.25rem}.settings-list-item[data-v-6d8dccc5]{padding:16px;min-height:72px}.setting-list-icon[data-v-6d8dccc5]{width:40px;height:40px;margin-right:12px}.settings-list-item[data-v-6d8dccc5] .v-list-item-title{font-size:1rem}.settings-list-item[data-v-6d8dccc5] .v-list-item-subtitle{font-size:.813rem}}
