import{d as u,g as d,a_ as f,u as o,b as p,ad as c,r as m,_ as b,e as g}from"./lucide-CCrbsyJI.js";import{g as v}from"./vueuse-FEBxOGD_.js";import{c as x}from"./index-Cpyo7KMo.js";const B=u({__name:"Input",props:{defaultValue:{},modelValue:{},class:{type:[Boolean,null,String,Object,Array]}},emits:["update:modelValue"],setup(a,{expose:s,emit:l}){const e=a,t=v(e,"modelValue",l,{passive:!0,defaultValue:e.defaultValue}),r=m(null);return s({focus:()=>{r.value?.focus()}}),(y,i)=>d((g(),p("input",{ref_key:"inputRef",ref:r,"onUpdate:modelValue":i[0]||(i[0]=n=>b(t)?t.value=n:null),"data-slot":"input",class:c(o(x)("file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm","focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px]","aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",e.class))},null,2)),[[f,o(t)]])}});export{B as _};
